# This file is part of Plus Plus Service.
# Copyright (C) 2016 The Fedora Project
#
# Plus Plus Service is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Plus Plus Service is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with Plus Plus Service.  If not, see <http://www.gnu.org/licenses/>.
#
# Authors:  Eric Barbour <atelic@fedoraproject.org>
#

import functools

import flask
from . import APP


def check_auth():
    token_str = None

    if 'Authorization' in flask.request.headers:
        authorization = flask.request.headers['Authorization']
        if 'token' in authorization:
            token_str = authorization.split('token', 1)[1].strip()

    if token_str == APP.config['PLUS_PLUS_TOKEN']:
        return

    output = {
        'error': 'Invalid token supplied',
    }
    jsonout = flask.jsonify(output)
    jsonout.status_code = 401
    return jsonout


def api_token_required():
    ''' Decorator used to indicate that authentication is required for some
    API endpoint.
    '''

    def decorator(fn):
        ''' The decorator of the function '''

        @functools.wraps(fn)
        def decorated_function(*args, **kwargs):
            ''' Actually does the job with the arguments provided. '''

            response = check_auth()
            if response:
                return response
            return fn(*args, **kwargs)

        return decorated_function

    return decorator
