# This file is part of Plus Plus Service.
# Copyright (C) 2016 The Fedora Project
#
# Plus Plus Service is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Plus Plus Service is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with Plus Plus Service.  If not, see <http://www.gnu.org/licenses/>.
#
# Authors:  Aurelien Bompard <abompard@fedoraproject.org>
#

import requests

from fedora.client.fas2 import AccountSystem


def make_fas_client():
    # Initialize FAS client
    # To get the information, we need a username and password to FAS.
    # DO NOT COMMIT YOUR USERNAME AND PASSWORD TO THE PUBLIC REPOSITORY!
    from . import APP
    return AccountSystem(
        APP.config["FAS_URL"],
        username=APP.config["FAS_USERNAME"],
        password=APP.config["FAS_PASSWORD"])


def _get_cache():
    from . import APP
    try:
        from werkzeug.contrib.cache import MemcachedCache
        cache = MemcachedCache(APP.config["MEMCACHED"])
    except (ImportError, KeyError):
        from werkzeug.contrib.cache import SimpleCache
        cache = SimpleCache()
    return cache
cache = _get_cache()


def get_current_release():
    cache_key = "current_release"
    release = cache.get(cache_key)
    if release is None:
        url = 'https://admin.fedoraproject.org/pkgdb/api/collections/'
        query = {
            'clt_status': 'Active',
            'pattern': 'f*',
        }
        response = requests.get(url, params=query)
        data = response.json()
        collections = data['collections']
        collections.sort(key=lambda c: int(c['version']))
        release = collections[-1]['branchname']
        cache.set(cache_key, release, timeout=3600)  # cache for 1 hour
    return release


# vim:set shiftwidth=4 tabstop=4 expandtab textwidth=79:
