# This file is part of Plus Plus Service.
# Copyright (C) 2016 The Fedora Project
#
# Plus Plus Service is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Plus Plus Service is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with Plus Plus Service.  If not, see <http://www.gnu.org/licenses/>.
#
# Authors:  Aurelien Bompard <abompard@fedoraproject.org>
#

import os
import tempfile
import unittest

from .. import APP
from ..database import Database


class TestCase(unittest.TestCase):

    def setUp(self):
        self._db_fd, self._db_filename = tempfile.mkstemp(
            prefix="flask-tests-", suffix=".db")
        APP.config['SQLALCHEMY_DATABASE_URI'] = "sqlite:///{}".format(
            self._db_filename)
        APP.config['TESTING'] = True
        self.client = APP.test_client()
        database = Database(
            APP.name, APP.config["SQLALCHEMY_DATABASE_URI"])
        database.create()
        self.db = database.get_session()

    def tearDown(self):
        self.db.rollback()
        from ..models import Base
        Base.metadata.drop_all(bind=self.db.connection())
        self.db.commit()
        self.db.close()
        os.close(self._db_fd)
        os.unlink(self._db_filename)
